@@ -4,7 +4,7 @@
 
 import pytest
 
-from vulcan_athena import vulcan_athena
+from vulcan_athena.vulcan_athena import sqrt_function, say_hello
 
 
 @pytest.fixture
@@ -24,4 +24,12 @@ def test_content(response):
 
 
 def test_sqrt_with_param():
-    assert vulcan_athena.sqrt_function(25) == 5
+    assert sqrt_function(25) == 5
+
+
+def test_helloworld_no_params():
+    assert say_hello() == 'Welcome to Athena...'
+
+
+def test_helloworld_with_param():
+    assert say_hello("Everyone") == "Welcome to Athena, Everyone!"
